        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==1 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==8 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==18 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==24 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==44 && cc==4){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==45 && cc==4){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
}
