        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 15 <br>1,9,11,13,15,16,20,21,26,33,34,39,40,47,49';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 15 <strong>control</strong><br>0,2,10,14,19,22,23,25,27,28,37,41,42,44,45';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 14 <br>3,4,6,7,8,12,18,30,31,32,35,43,46,48';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260510 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 7 <br>5,17,24,29,36,38,50';}
}
